# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'CloudInitDataSource',
    'CreatedByType',
    'DiagnosticLevel',
    'DiskFileFormat',
    'ExtendedLocationTypes',
    'HyperVGeneration',
    'IPPoolTypeEnum',
    'IpAllocationMethodEnum',
    'NetworkTypeEnum',
    'OperatingSystemTypes',
    'OsTypeEnum',
    'PrivateIPAllocationMethodEnum',
    'ProvisioningAction',
    'ResourceIdentityType',
    'WindowsServerSubscription',
]


class CloudInitDataSource(str, Enum):
    """
    Datasource for the gallery image when provisioning with cloud-init [Azure, NoCloud]
    """
    NO_CLOUD = "NoCloud"
    AZURE = "Azure"


class CreatedByType(str, Enum):
    """
    The type of identity that last modified the resource.
    """
    USER = "User"
    APPLICATION = "Application"
    MANAGED_IDENTITY = "ManagedIdentity"
    KEY = "Key"


class DiagnosticLevel(str, Enum):
    """
    Desired level of diagnostic data emitted by the cluster.
    """
    OFF = "Off"
    BASIC = "Basic"
    ENHANCED = "Enhanced"


class DiskFileFormat(str, Enum):
    """
    The format of the actual VHD file [vhd, vhdx]
    """
    VHDX = "vhdx"
    VHD = "vhd"


class ExtendedLocationTypes(str, Enum):
    """
    The type of the extended location.
    """
    CUSTOM_LOCATION = "CustomLocation"


class HyperVGeneration(str, Enum):
    """
    The hypervisor generation of the Virtual Machine [V1, V2]
    """
    V1 = "V1"
    V2 = "V2"


class IPPoolTypeEnum(str, Enum):
    """
    ip pool type
    """
    VM = "vm"
    VIPPOOL = "vippool"


class IpAllocationMethodEnum(str, Enum):
    """
    IPAllocationMethod - The IP address allocation method. Possible values include: 'Static', 'Dynamic'
    """
    DYNAMIC = "Dynamic"
    STATIC = "Static"


class NetworkTypeEnum(str, Enum):
    """
    Type of the network
    """
    NAT = "NAT"
    TRANSPARENT = "Transparent"
    L2_BRIDGE = "L2Bridge"
    L2_TUNNEL = "L2Tunnel"
    ICS = "ICS"
    PRIVATE = "Private"
    OVERLAY = "Overlay"
    INTERNAL = "Internal"
    MIRRORED = "Mirrored"


class OperatingSystemTypes(str, Enum):
    """
    operating system type that the gallery image uses. Expected to be linux or windows
    """
    WINDOWS = "Windows"
    LINUX = "Linux"


class OsTypeEnum(str, Enum):
    """
    OsType - string specifying whether the OS is Linux or Windows
    """
    LINUX = "Linux"
    WINDOWS = "Windows"


class PrivateIPAllocationMethodEnum(str, Enum):
    """
    PrivateIPAllocationMethod - The private IP address allocation method. Possible values include: 'Static', 'Dynamic'
    """
    DYNAMIC = "Dynamic"
    STATIC = "Static"


class ProvisioningAction(str, Enum):
    """
    The guest agent provisioning action.
    """
    INSTALL = "install"
    UNINSTALL = "uninstall"
    REPAIR = "repair"


class ResourceIdentityType(str, Enum):
    """
    The identity type.
    """
    SYSTEM_ASSIGNED = "SystemAssigned"


class WindowsServerSubscription(str, Enum):
    """
    Desired state of Windows Server Subscription.
    """
    DISABLED = "Disabled"
    ENABLED = "Enabled"
