# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ManagedIdentityTypes',
    'MonitoringStatus',
]


class ManagedIdentityTypes(str, Enum):
    """
    Identity type
    """
    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"


class MonitoringStatus(str, Enum):
    """
    Flag specifying if the resource monitoring is enabled or disabled.
    """
    ENABLED = "Enabled"
    DISABLED = "Disabled"
