# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .addon import *
from .arc_addon import *
from .bandwidth_schedule import *
from .cloud_edge_management_role import *
from .container import *
from .device import *
from .file_event_trigger import *
from .get_addon import *
from .get_arc_addon import *
from .get_bandwidth_schedule import *
from .get_cloud_edge_management_role import *
from .get_container import *
from .get_device import *
from .get_device_extended_information import *
from .get_file_event_trigger import *
from .get_io_t_addon import *
from .get_io_t_role import *
from .get_kubernetes_role import *
from .get_mec_role import *
from .get_monitoring_config import *
from .get_order import *
from .get_periodic_timer_event_trigger import *
from .get_role import *
from .get_share import *
from .get_storage_account import *
from .get_storage_account_credential import *
from .get_trigger import *
from .get_user import *
from .io_t_addon import *
from .io_t_role import *
from .kubernetes_role import *
from .list_order_dc_access_code import *
from .mec_role import *
from .monitoring_config import *
from .order import *
from .periodic_timer_event_trigger import *
from .role import *
from .share import *
from .storage_account import *
from .storage_account_credential import *
from .trigger import *
from .user import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.databoxedge.v20190301 as __v20190301
    v20190301 = __v20190301
    import pulumi_azure_native.databoxedge.v20190701 as __v20190701
    v20190701 = __v20190701
    import pulumi_azure_native.databoxedge.v20190801 as __v20190801
    v20190801 = __v20190801
    import pulumi_azure_native.databoxedge.v20200501preview as __v20200501preview
    v20200501preview = __v20200501preview
    import pulumi_azure_native.databoxedge.v20200901 as __v20200901
    v20200901 = __v20200901
    import pulumi_azure_native.databoxedge.v20200901preview as __v20200901preview
    v20200901preview = __v20200901preview
    import pulumi_azure_native.databoxedge.v20201201 as __v20201201
    v20201201 = __v20201201
    import pulumi_azure_native.databoxedge.v20210201 as __v20210201
    v20210201 = __v20210201
    import pulumi_azure_native.databoxedge.v20210201preview as __v20210201preview
    v20210201preview = __v20210201preview
    import pulumi_azure_native.databoxedge.v20210601 as __v20210601
    v20210601 = __v20210601
    import pulumi_azure_native.databoxedge.v20210601preview as __v20210601preview
    v20210601preview = __v20210601preview
    import pulumi_azure_native.databoxedge.v20220301 as __v20220301
    v20220301 = __v20220301
    import pulumi_azure_native.databoxedge.v20220401preview as __v20220401preview
    v20220401preview = __v20220401preview
    import pulumi_azure_native.databoxedge.v20221201preview as __v20221201preview
    v20221201preview = __v20221201preview
    import pulumi_azure_native.databoxedge.v20230101preview as __v20230101preview
    v20230101preview = __v20230101preview
else:
    v20190301 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20190301')
    v20190701 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20190701')
    v20190801 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20190801')
    v20200501preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20200501preview')
    v20200901 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20200901')
    v20200901preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20200901preview')
    v20201201 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20201201')
    v20210201 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20210201')
    v20210201preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20210201preview')
    v20210601 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20210601')
    v20210601preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20210601preview')
    v20220301 = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20220301')
    v20220401preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20220401preview')
    v20221201preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20221201preview')
    v20230101preview = _utilities.lazy_import('pulumi_azure_native.databoxedge.v20230101preview')

