# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'DomainManagement',
    'UserEngagementTracking',
]


class DomainManagement(str, Enum):
    """
    Describes how a Domains resource is being managed.
    """
    AZURE_MANAGED = "AzureManaged"
    CUSTOMER_MANAGED = "CustomerManaged"
    CUSTOMER_MANAGED_IN_EXCHANGE_ONLINE = "CustomerManagedInExchangeOnline"


class UserEngagementTracking(str, Enum):
    """
    Describes whether user engagement tracking is enabled or disabled.
    """
    DISABLED = "Disabled"
    ENABLED = "Enabled"
