# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'SkuName',
    'WebhookAction',
    'WebhookStatus',
]


class SkuName(str, Enum):
    """
    The SKU name of the container registry. Required for registry creation.
    """
    BASIC = "Basic"
    MANAGED_BASIC = "Managed_Basic"
    MANAGED_STANDARD = "Managed_Standard"
    MANAGED_PREMIUM = "Managed_Premium"


class WebhookAction(str, Enum):
    PUSH = "push"
    DELETE = "delete"


class WebhookStatus(str, Enum):
    """
    The status of the webhook at the time the operation was called.
    """
    ENABLED = "enabled"
    DISABLED = "disabled"
